/* Notice that this import includes the android subdirectory */
import junctionbox.android.*;
/* This import is required */
import android.view.MotionEvent;

/* For this sketch to run properly, the INTERNET permission must be set!
   Check the INTERNET box in Android>Sketch Permissions */

/* Declare JunctionBox classes */
Dispatcher dispatcher;
Junction junction1;
String state1;
Junction junction2;
String state2;

void setup() {
  /* The Dispatcher routes touch input to Junctions
     NOTE: The box size for the Dispatcher should always be the display size */
  dispatcher = new Dispatcher(displayWidth, displayHeight, "127.0.0.1", 7000);
  
  /* Junctions are areas of the interface that respond to touch input.
     In creating this Junction, the Dispatcher now knows whether to route touches
     to it based the Junction's location and area */
  junction1 = dispatcher.createJunction(width/3, height/2, width/4, height/4);
  junction2 = dispatcher.createJunction(2*width/3, height/2, width/4, height/4);
  
  /* Junctions can have 2 different shapes, rectangle and ellipse
     NOTE: RECT is the default if no shape is specified */
  junction1.setShape(ELLIPSE);
  junction2.setShape(ELLIPSE);
  
  /* An OSC message can be sent when a Junction is active (has at least one touch)
     and then again when all touches have been removed */
  junction1.mapMessage(Action.ACTIVATE, "/activate");
  
  /* An OSC message can be sent when the state of the Junction is toggled */
  junction2.mapMessage(Action.TOGGLE, "/toggle");

  /* Shapes must be set to CENTER mode or touches will not route properly */
  ellipseMode(CENTER);
  rectMode(CENTER);
  
  strokeWeight(4);
  smooth();
  
  textAlign(CENTER, CENTER);
  textSize(24);
}

void draw() {
  background(200);
  
  /* When a touch occurs inside of the Junction, make it green */
  if (junction1.isActive()) {
    fill(0, 255, 0);
    state1 = "Active";
  }
  else {
    fill(255);
    state1 = "Not Active";
  }
  
  /* Changing the shape in setup() should work without having to change this code */
  if (junction1.getShape() == RECT) {
    rect(junction1.getCenterX(), junction1.getCenterY(), junction1.getWidth(), junction1.getHeight());
  }
  else {
    ellipse(junction1.getCenterX(), junction1.getCenterY(), junction1.getWidth(), junction1.getHeight());
  }
  
  fill(0);
  text(state1, width/3, height/2);
  
  /* When the Junction is toggled, make it green */
  if (junction2.getToggle()) {
    fill(0, 255, 0);
    state2 = "Toggled";
  }
  else {
    fill(255);
    state2 = "Not Toggled";
  }
  
  /* Changing the shape in setup() should work without having to change this code */
  if (junction2.getShape() == RECT) {
    rect(junction2.getCenterX(), junction2.getCenterY(), junction2.getWidth(), junction2.getHeight());
  }
  else {
    ellipse(junction2.getCenterX(), junction2.getCenterY(), junction2.getWidth(), junction2.getHeight());
  }
  
  fill(0);
  text(state2, 2*width/3, height/2);
}

/* This method must be here to route touch events in Android */
public boolean dispatchTouchEvent(MotionEvent ev) {
  dispatcher.handleMotionEvent(ev);
  return true;
}
