import junctionbox.*;

Dispatcher dispatcher;
Simulator simulator;
Junction junction;

void setup() {
  size(800, 800);
  
  dispatcher = new Dispatcher(width, height, "127.0.0.1", 7000);
  
  simulator = new Simulator(width, height);

  junction = dispatcher.createJunction(width/2, height/2, 400, 600);
  
  junction.setShape(ELLIPSE);
  //junction.setShape(RECT);
  
  /* NOTE: Rotation is not allowed by default */
  junction.allowRotation(true);
  
  /* Set angle limits in radians */
  //junction.limitRotation(0-TWO_PI, TWO_PI);
  
  /* OSC messages can be mapped to both the current angle and the number of rotations */
  junction.mapMessage(Action.ROTATE, "/rotate");
  junction.mapMessage(Action.COUNT_ROTATIONS, "/count/rotations");

  ellipseMode(CENTER);
  rectMode(CENTER);
  
  cursor(HAND);
  smooth();

  textSize(24);
}

void draw() {
  background(200);

  simulator.mouse(mousePressed, mouseButton, mouseX, mouseY, pmouseX, pmouseY);

  fill(0);
  strokeWeight(4);

  /* Show the current angle and the rotation count */
  text("Angle change: " + junction.getAngle(), 30, 50);
  text("Rotations: " + junction.getRotationCount(), 30, 80);

  if (junction.isActive()) {
    fill(0, 255, 0);
  }
  else {
    fill(255);
  }

  pushMatrix();
  translate(junction.getCenterX(), junction.getCenterY());
  rotate(junction.getAngle());
  
  if (junction.getShape() == ELLIPSE) {
    ellipse(0, 0, junction.getWidth(), junction.getHeight());
  }
  else {
    rect(0, 0, junction.getWidth(), junction.getHeight());
  }
  
  /* Small circles to help track rotation */
  fill(255, 0, 0);
  ellipse(0, 0+junction.getHeight()/2, 20, 20);
  fill(0, 0, 255);
  ellipse(0, 0-junction.getHeight()/2, 20, 20);
  
  popMatrix();
}

