import junctionbox.*;

Dispatcher dispatcher;
Junction junction;
Simulator simulator;
Contact[] touches;

void setup() {
  size(800, 800);
  
  dispatcher = new Dispatcher(width, height, "127.0.0.1", 7000);
  
  simulator = new Simulator(width, height);
  
  junction = dispatcher.createJunction(width/2, height/2, 400, 600);
  
  junction.setShape(ELLIPSE);
  
  /* This mapping works for rectangles and ellipses */
  junction.mapMessage(Action.CONTACT, "/contact/all");
  
  /* The following mappings are for rectangles only */
  //junction.mapMessage(Action.CONTACT_X, "/contact/x");
  //junction.mapMessage(Action.CONTACT_Y, "/contact/y");
  
  /* This mapping works for ellipses */
  junction.mapMessage(Action.CONTACT_R, "/contact/r");
  junction.mapMessage(Action.CONTACT_THETA, "/contact/theta");
  
  /* Messages can be sent whenever the number of touches changes */
  //junction.mapMessage(Action.COUNT_CONTACTS, "/count/contacts");
  
  ellipseMode(CENTER);
  rectMode(CENTER);
  
  cursor(HAND);
  strokeWeight(4);
  smooth();
  
  textSize(24);
}

void draw() {
  background(200);
  
  simulator.mouse(mousePressed, mouseButton, mouseX, mouseY, pmouseX, pmouseY);
  
  if (junction.isActive()) {
    fill(0, 255, 0);
  }
  else {
    fill(255);
  }
  
  if (junction.getShape() == RECT) {
    rect(junction.getCenterX(), junction.getCenterY(), junction.getWidth(), junction.getHeight());
  }
  else {
    ellipse(junction.getCenterX(), junction.getCenterY(), junction.getWidth(), junction.getHeight());
    fill(0);
    ellipse(junction.getCenterX(), junction.getCenterY(), 50, 50);
  }
  
  touches = junction.getContacts();
  
  /* Display a blue circle for each touch */
  for (int i = 0; i < touches.length; i++) {
    fill(0, 0, 255);
    ellipse(touches[i].getX(), touches[i].getY(), 50, 50);
  }
  
  /* Show the touch count inside the Junction */
  fill(0);
  text("Contact count: " + junction.getContactCount(), 30, 50);
}

