import junctionbox.*;

Simulator simulator;
Dispatcher dispatcher;

Junction junction1;
Junction junction2;

Junction save;
Junction load;
Junction reset;

void setup() {
  size(800, 800);
  
  simulator = new Simulator(width, height);
  dispatcher = new Dispatcher(width, height);
  
  junction1 = dispatcher.createJunction(width/3, height/2, 200, 200);
  junction1.allowTranslation(true);
  junction1.setLabel("1");
  junction1.allowSaving(true);
  
  junction2 = dispatcher.createJunction(2*width/3, height/2, 200, 200);
  junction2.allowTranslation(true);
  junction2.setShape(ELLIPSE);
  junction2.setLabel("2");
  junction2.allowSaving(true);
  
  save = dispatcher.createJunction(width/4, height-80, 120, 60);
  load = dispatcher.createJunction(width/2, height-80, 120, 60);
  reset = dispatcher.createJunction(3*width/4, height-80, 120, 60);
  
  rectMode(CENTER);
  cursor(HAND);
  strokeWeight(4);
  textAlign(CENTER, CENTER);
  smooth();
}

void draw() {
  background(200);
  
  simulator.mouse(mousePressed, mouseButton, mouseX, mouseY, pmouseX, pmouseY);
  
  fill(0);
  strokeWeight(4);
  
  // Get an array with the current Junction order
  Junction[] holder = dispatcher.getJunctions();
  int l = holder.length;
  
  for (int i = 0; i < l; i++) {
    Junction j = holder[i];
    
    if (j.isActive()) {
      fill(0, 255, 0);
    }
    else {
      fill(255);
    }
    
    if (j.getShape() == ELLIPSE) {
      ellipse(j.getCenterX(), j.getCenterY(), j.getWidth(), j.getHeight());
    }
    else {
      rect(j.getCenterX(), j.getCenterY(), j.getWidth(), j.getHeight());
    }
    fill(0);
    
    textSize(60);
    text(j.getLabel(), j.getCenterX(), j.getCenterY());
    
    if (j.isActive()) {
      // Move to the end of the list
      dispatcher.orderJunction(l-1, j);
    }
  }
  
  textSize(24);
  
  /* Save button */
  if (save.getToggle()){
    dispatcher.saveXML(createOutput("junctions.xml"));
    save.setToggle(false);
  }
  if (save.isActive()) {
    fill(0, 255, 0);
  }
  else {
    fill(255);
  }
  rect(save.getCenterX(), save.getCenterY(), save.getWidth(), save.getHeight());
  fill(0);
  text("Save", save.getCenterX(), save.getCenterY());
  
  /* Load button */
  if (load.getToggle()) {
    dispatcher.loadXML(createInput("junctions.xml"));
    load.setToggle(false);
  }
  if (load.isActive()) {
    fill(0, 255, 0);
  }
  else {
    fill(255);
  }
  rect(load.getCenterX(), load.getCenterY(), load.getWidth(), load.getHeight());
  fill(0);
  text("Load", load.getCenterX(), load.getCenterY());
  
  /* Reset button */
  if (reset.getToggle()) {
    junction1.setCenter(width/3, height/2);
    junction2.setCenter(2*width/3, height/2);
    reset.setToggle(false);
  }
  if (reset.isActive()) {
    fill(0, 255, 0);
  }
  else {
    fill(255);
  }
  rect(reset.getCenterX(), reset.getCenterY(), reset.getWidth(), reset.getHeight());
  fill(0);
  text("Reset", reset.getCenterX(), reset.getCenterY());
}

