import junctionbox.*;

Dispatcher dispatcher;
Simulator simulator;
Junction record;
Junction stop;
Junction play;
Junction looper;
Junction clear;
Junction save;
Junction load;
Junction scaler;
Junction gestureArea;
Junction slider;
Contact[] touches;
InputStream in;
OutputStream out;
ArrayList<Contact> touchList;
float shade = 255;
boolean recording = false;
float oldScalerX = 0;
float newScalerX = 0;
float scaleValue = 1.0;
float areaWidth;
float areaHeight;
float buttonWidth;
float buttonHeight;

void setup() {
  size(1280, 800);
  
  areaWidth = 0.8*width;
  areaHeight = 0.7*height;
  buttonWidth = 0.07*width;
  buttonHeight = 0.08*height;
  
  dispatcher = new Dispatcher(width, height, "127.0.0.1", 7000);
  
  simulator = new Simulator(width, height);
  
  record = dispatcher.createJunction(0.07*width, height/9, buttonWidth, buttonHeight);
  play = dispatcher.createJunction(0.07*width, 2*height/9, buttonWidth, buttonHeight);
  looper = dispatcher.createJunction(0.07*width, height/3, buttonWidth, buttonHeight);
  stop = dispatcher.createJunction(0.07*width, 4*height/9, buttonWidth, buttonHeight);
  clear = dispatcher.createJunction(0.07*width, 5*height/9, buttonWidth, buttonHeight);
  scaler = dispatcher.createJunction(0.07*width, 2*height/3, buttonWidth, buttonHeight);
  save = dispatcher.createJunction(0.07*width, 7*height/9, buttonWidth, buttonHeight);
  load = dispatcher.createJunction(0.07*width, 8*height/9, buttonWidth, buttonHeight);
  
  
  gestureArea = dispatcher.createJunction(width/2+buttonHeight, height/2-buttonHeight, areaWidth, areaHeight);
  gestureArea.allowRecording(true);
  gestureArea.mapMessage(Action.CONTACT, "/contact/xy");
  gestureArea.mapMessage(Action.COUNT_CONTACTS, "/contact/count");
  gestureArea.mapMessage(Action.ACTIVATE, "/activate");
  
  slider = dispatcher.createJunction(0.36*width, 8*height/9, buttonHeight, buttonHeight);
  slider.allowTranslation(true);
  slider.allowTranslationY(false);
  slider.limitTranslationX(0.18*width, 0.9*width);
  oldScalerX = slider.getCenterX();
  
  touchList = new ArrayList<Contact>();
  
  rectMode(CENTER);
  cursor(HAND);
  smooth();
  textSize(24);
  textAlign(CENTER, CENTER);
}

void draw() {
  background(200);
  
  simulator.mouse(mousePressed, mouseButton, mouseX, mouseY, pmouseX, pmouseY);
  
  touches = gestureArea.getContacts();
  
  //stroke(0);
  //strokeWeight(4);
  noStroke();
  
  // Record button
  if (record.getToggle()) {
    if (!recording) {
      dispatcher.startRecording();
      recording = true;
      record.setToggle(false);
    }
    else {
      dispatcher.stopRecording();
      recording = false;
      record.setToggle(false);
      touchList.clear();
    }
  }
  
  if (recording) {
    fill(255, 0, 0);
  }
  else {
    fill(128, 0, 0);
  }
  rect(record.getCenterX(), record.getCenterY(), record.getWidth(), record.getHeight());
  fill(0);
  ellipse(record.getCenterX(), record.getCenterY(), 20, 20);
  
  // Play button
  if (play.getToggle()) {
    dispatcher.startPlaying();
    play.setToggle(false);
  }
  
  if (dispatcher.isPlaying()) {
    fill(0, 255, 0);
  }
  else {
    fill(0, 128, 0);
  }
  rect(play.getCenterX(), play.getCenterY(), play.getWidth(), play.getHeight());
  fill(0);
  triangle(play.getCenterX()-10, play.getCenterY()-10,
           play.getCenterX()-10, play.getCenterY()+10,
           play.getCenterX()+10, play.getCenterY());
  
  // Loop button
  if (looper.getToggle()) {
    if (dispatcher.isLooping()) {
      dispatcher.stopLooping();
    }
    else {
      dispatcher.startLooping();
    }
    looper.setToggle(false);
  }
  
  if (dispatcher.isLooping()) {
    fill(0, 255, 255);
  }
  else {
    fill(0, 128, 128);
  }
  rect(looper.getCenterX(), looper.getCenterY(), looper.getWidth(), looper.getHeight());
  stroke(0);
  strokeWeight(4);
  ellipse(looper.getCenterX(), looper.getCenterY(), 20, 20);
  
  noStroke();
  // Stop button
  if (stop.getToggle()) {
    dispatcher.stopPlaying();
    stop.setToggle(false);
  }
  
  if (stop.isActive()) {
    fill(0, 0, 255);
  }
  else {
    fill(0, 0, 128);
  }
  rect(stop.getCenterX(), stop.getCenterY(), stop.getWidth(), stop.getHeight());
  fill(0);
  rect(stop.getCenterX(), stop.getCenterY(), 20, 20);
  
  // Clear button
  if (clear.getToggle()) {
    dispatcher.clearEvents();
    clear.setToggle(false);
    touchList.clear();
  }
  
  if (clear.isActive()) {
    fill(255);
  }
  else {
    fill(240);
  }
  rect(clear.getCenterX(), clear.getCenterY(), clear.getWidth(), clear.getHeight());
  stroke(0);
  strokeWeight(4);
  rect(clear.getCenterX(), clear.getCenterY(), 20, 20);
  
  noStroke();
  // Scale button
  if (scaler.getToggle()) {
    if (dispatcher.getEventCount() > 0) {
      dispatcher.scaleEventTimes((double)scaleValue);
    }
    scaler.setToggle(false);
  }
  if (scaler.isActive()) {
    fill(240, 160, 30);
  }
  else {
    fill(150, 100, 10);
  }
  rect(scaler.getCenterX(), scaler.getCenterY(), scaler.getWidth(), scaler.getHeight());
  stroke(0);
  strokeWeight(4);
  line(scaler.getCenterX()+12, scaler.getCenterY(), scaler.getCenterX()-12, scaler.getCenterY());
  triangle(scaler.getCenterX()+15, scaler.getCenterY(), scaler.getCenterX()+12, scaler.getCenterY()+5, scaler.getCenterX()+12, scaler.getCenterY()-5);
  triangle(scaler.getCenterX()-15, scaler.getCenterY(), scaler.getCenterX()-12, scaler.getCenterY()+5, scaler.getCenterX()-12, scaler.getCenterY()-5);
  
  noStroke();
  // Save button
  if (save.getToggle()){
    dispatcher.saveXML(createOutput("events.xml"));
    save.setToggle(false);
  }
  if (save.isActive()) {
    fill(200);
  }
  else {
    fill(160);
  }
  rect(save.getCenterX(), save.getCenterY(), save.getWidth(), save.getHeight());
  fill(0);
  text("Save", save.getCenterX(), save.getCenterY());
  
  // Load button
  if (load.getToggle()) {
    dispatcher.loadXML(createInput("events.xml"));
    load.setToggle(false);
  }
  if (load.isActive()) {
    fill(200);
  }
  else {
    fill(160);
  }
  rect(load.getCenterX(), load.getCenterY(), load.getWidth(), load.getHeight());
  fill(0);
  text("Load", load.getCenterX(), load.getCenterY());
  
  // Gesture area
  fill(255, 255, 0);
  rect(gestureArea.getCenterX(), gestureArea.getCenterY(), gestureArea.getWidth(), gestureArea.getHeight());
  fill(0);
  text("Gesture time: " + dispatcher.getRecordTime()/1000000 + " ms", gestureArea.getCenterX(), gestureArea.getCenterY());
  
  stroke(0);
  strokeWeight(2);
  // Scaling slider
  newScalerX = slider.getCenterX();
  if (oldScalerX != newScalerX) {
    scaleValue = map(newScalerX, slider.getMinTranslationX(), slider.getMaxTranslationX(), 0.0, 4.0);
    oldScalerX = newScalerX;
  }
  fill(200);
  line(slider.getMinTranslationX()-40, slider.getCenterY(), slider.getMaxTranslationX()+40, slider.getCenterY());
  fill(150, 100, 10);
  rect(slider.getCenterX(), slider.getCenterY(), slider.getWidth(), slider.getHeight());
  fill(0);
  text("0.0", slider.getMinTranslationX()-20, slider.getCenterY()-20);
  text(str(scaleValue), slider.getCenterX(), slider.getCenterY()-60);
  text("4.0", slider.getMaxTranslationX()+20, slider.getCenterY()-20);
  
  stroke(0);
  strokeWeight(8);
  noFill();
  
  if (gestureArea.isActive()) {
    beginShape();
    for (Contact c : touchList) {
      curveVertex(c.getX(), c.getY());
    }
    endShape();
  }
  else {
    touchList.clear();
  }
  
  for (int i = 0; i < touches.length; i++) {
    Contact c = (Contact)touches[i];
    touchList.add(c);
    fill(0);
    ellipse(c.getX(), c.getY(), 80, 80);
    fill(255);
    text(c.getID(), c.getX(), c.getY());
  }
}

