import junctionbox.*;

/* For JunctionBox to work properly, TUIO must be enabled!
   See http://www.tuio.org/ for more information */

Dispatcher dispatcher;
Junction junction;

void setup() {
  size(displayWidth, displayHeight);
  
  dispatcher = new Dispatcher(displayWidth, displayHeight, "127.0.0.1", 7000);

  junction = dispatcher.createJunction(displayWidth/2, displayHeight/2, 400, 600);
  
  /* Either shape can be rotated easily */
  junction.setShape(ELLIPSE);
  //junction.setShape(RECT);
  
  /* NOTE: Rotation is not allowed by default */
  /* This enables 1 and 2 touch rotation */
  //junction.allowRotation(true);
  
  /* Allow 2-touch rotation */
  junction.allowRotation(true, 2);
  
  /* Set angle limits in radians */
  //junc.limitRotation(0, TWO_PI);
  
  /* OSC messages can be mapped to both the current angle and the number of rotations */
  junction.mapMessage(Action.ROTATE, "/rotate");
  junction.mapMessage(Action.COUNT_ROTATIONS, "/count/rotations");

  ellipseMode(CENTER);
  rectMode(CENTER);
  
  noCursor();
  strokeWeight(4);
  smooth();

  textSize(24);
}

void draw() {
  background(200);
  
  fill(0);
  strokeWeight(4);

  /* Show the current angle and the rotation count */
  text("Angle: " + junction.getAngle(), 30, 50);
  text("Rotations: " + junction.getRotationCount(), 30, 80);

  if (junction.isActive()) {
    fill(0, 255, 0);
  }
  else {
    fill(255);
  }
  
  pushMatrix();
  translate(junction.getCenterX(), junction.getCenterY());
  rotate(junction.getAngle());
  
  if (junction.getShape() == ELLIPSE) {
    ellipse(0, 0, junction.getWidth(), junction.getHeight());
  }
  else {
    rect(0, 0, junction.getWidth(), junction.getHeight());
  }
  
  /* Small circles to help track rotation */
  fill(255, 0, 0);
  ellipse(0, 0+junction.getHeight()/2, 20, 20);
  fill(0, 0, 255);
  ellipse(0, 0-junction.getHeight()/2, 20, 20);
  popMatrix();
}

